package digi.recipeManager;

import net.milkbowl.vault.Vault;
import net.milkbowl.vault.economy.Economy;

import org.bukkit.Bukkit;
import org.bukkit.plugin.RegisteredServiceProvider;

import com.iCo6.iConomy;
import com.iCo6.system.Accounts;
import com.nijikokun.register.Register;
import com.nijikokun.register.payment.*;

public final class Econ
{
	private Economy		vaultEcon		= null;
	private Method		registerEcon	= null;
	private Accounts	iConomyEcon		= null;
	private boolean		enabled			= false;
	
	protected Econ()
	{
		if(Bukkit.getPluginManager().getPlugin("Vault") instanceof Vault)
		{
			final RegisteredServiceProvider<Economy> service = Bukkit.getServicesManager().getRegistration(net.milkbowl.vault.economy.Economy.class);
			
			if(service != null)
			{
				vaultEcon = service.getProvider();
				
				if(vaultEcon != null)
					Bukkit.getLogger().fine("Vault detected and connected, economy available.");
			}
		}
		else if(Bukkit.getPluginManager().getPlugin("Register") instanceof Register)
		{
			registerEcon = Methods.getMethod();
			
			if(registerEcon != null)
				Bukkit.getLogger().fine("Register detected and connected, economy available.");
		}
		else if(Bukkit.getPluginManager().getPlugin("iConomy") instanceof iConomy)
		{
			iConomyEcon = new Accounts();
			
			if(iConomyEcon != null)
				Bukkit.getLogger().fine("iConomy detected and connected, economy available.");
		}
		
		enabled = (vaultEcon != null || registerEcon != null || iConomyEcon != null);
	}
	
	/**
	 * Checks if you can use economy methods
	 * 
	 * @return true if economy plugin detected, false otherwise
	 */
	public boolean isEnabled()
	{
		return enabled;
	}
	
	/**
	 * Gets the format of the money, defined by the economy plugin used.
	 * If economy is not enabled this method will return null.
	 * 
	 * @param amount
	 *            money amount to format
	 * @return String with formatted money
	 */
	public String getFormat(final double amount)
	{
		if(!enabled)
			return null;
		
		if(vaultEcon != null)
			return vaultEcon.format(amount);
		else if(registerEcon != null)
			return registerEcon.format(amount);
		else if(iConomyEcon != null)
			return iConomy.format(amount);
		
		return null;
	}
	
	/**
	 * Gets how much money a player has
	 * If economy is not enabled this method will return 0.
	 * 
	 * @param playerName
	 *            player's name
	 * @return money player has, 0 if no economy plugin was found
	 */
	public double getMoney(final String playerName)
	{
		if(!enabled)
			return 0;
		
		if(vaultEcon != null)
			return vaultEcon.getBalance(playerName);
		else if(registerEcon != null)
			return registerEcon.getAccount(playerName).balance();
		else if(iConomyEcon != null)
			return iConomyEcon.get(playerName).getHoldings().getBalance();
		
		return 0;
	}
	
	/**
	 * Give money to player.
	 * Use negative values to take money.
	 * If economy is not enabled or amount is 0, this method won't do anything
	 * 
	 * @param playerName
	 *            player's name
	 * @param amount
	 *            amount to give
	 */
	public void giveMoney(final String playerName, final double amount)
	{
		if(!enabled || amount == 0)
			return;
		
		if(vaultEcon != null)
			vaultEcon.depositPlayer(playerName, amount);
		else if(registerEcon != null)
			registerEcon.getAccount(playerName).add(amount);
		else if(iConomyEcon != null)
			iConomyEcon.get(playerName).getHoldings().add(amount);
		
		/*
		if(amount > 0)
		{
			
		}
		else
		{
			if(vaultEcon != null)
				vaultEcon.withdrawPlayer(playerName, Math.abs(amount));
			else if(registerEcon != null)
				registerEcon.getAccount(playerName).subtract(Math.abs(amount));
			else if(iConomyEcon != null)
				iConomyEcon.get(playerName).getHoldings().subtract(Math.abs(amount));
		}
		*/
	}
}
