package digi.recipeManager;

import java.util.*;
import java.util.Map.Entry;

import org.bukkit.Material;
import org.bukkit.block.Furnace;
import org.bukkit.inventory.FurnaceInventory;

import digi.recipeManager.data.Smelt;

public class FurnacesTask implements Runnable
{
	@Override
	public void run()
	{
		final Iterator<Entry<String, Double>> iterator = RecipeManager.getRecipes().furnaces.entrySet().iterator();
		
		Entry<String, Double> entry;
		String locString;
		Furnace furnace;
		FurnaceInventory inventory;
		Smelt recipe;
		double time;
		
		while(iterator.hasNext())
		{
			entry = iterator.next();
			locString = entry.getKey();
			furnace = Recipes.stringToFurnace(locString);
			
			if(furnace == null)
			{
				iterator.remove();
				
				final Recipes recipes = RecipeManager.getRecipes();
				recipes.smelters.remove(locString);
				recipes.fuelers.remove(locString);
				recipes.fueled.remove(locString);
				
				continue;
			}
			
			inventory = furnace.getInventory();
			
			// if there's nothing to smelt, skip furnace
			if(inventory.getSmelting() == null || inventory.getSmelting().getType() == Material.AIR)
			{
				entry.setValue(0.0);
				continue;
			}
			
			recipe = RecipeManager.getRecipes().getSmeltRecipe(inventory.getSmelting());
			
			// No custom recipe for item or it has default time
			if(recipe == null || recipe.getMinTime() <= -1.0)
			{
				entry.setValue(0.0);
				continue;
			}
			
			// If the result already in the furnace is something else than the recipe OR result is already max stacks, skip furnace
			if(inventory.getResult() != null && (!recipe.getResult().compareItemStack(inventory.getResult()) || inventory.getResult().getAmount() >= inventory.getResult().getType().getMaxStackSize()))
			{
				entry.setValue(0.0);
				continue;
			}
			
			if(recipe.getMinTime() == 0.0)
			{
				furnace.setCookTime((short)200);
			}
			else if(recipe.getMinTime() > 0.0)
			{
				time = entry.getValue();
				
				if(time >= 200 || furnace.getCookTime() == 0 || furnace.getCookTime() >= 200)
				{
					entry.setValue(0.0);
				}
				else
				{
					time = time + ((10 / RecipeManager.getSettings().FURNACE_TICKS) / recipe.getTime());
					furnace.setCookTime((short)time);
					entry.setValue(time);
				}
			}
		}
	}
}
