package digi.recipeManager.customEvents;

import org.bukkit.entity.Player;
import org.bukkit.event.*;
import org.bukkit.inventory.ItemStack;

import digi.recipeManager.data.*;

public class RecipeManagerCraftEvent extends Event implements Cancellable
{
	private static final HandlerList	handlers	= new HandlerList();
	private boolean						cancelled	= false;
	private Item						result;
	private final Recipe				recipe;
	private final Player				player;
	
	public RecipeManagerCraftEvent(final Recipe recipe, final Item result, final Player player)
	{
		this.recipe = recipe;
		this.result = result;
		this.player = player;
	}
	
	public Player getPlayer()
	{
		return player;
	}
	
	public Recipe getRecipe()
	{
		return recipe;
	}
	
	/**
	 * @return result item or null if chance of failure occured
	 */
	public Item getResult()
	{
		return result;
	}
	
	/**
	 * Sets the result to the specified item.
	 * 
	 * @param result
	 *            the Item result
	 */
	public void setResult(final Item result)
	{
		this.result = result;
	}
	
	/**
	 * Sets the result to the specified item.<br>
	 * Shortcut for: setResult(new Item(result));
	 * 
	 * @param result
	 *            the ItemStack result
	 */
	public void setResult(final ItemStack result)
	{
		setResult(new Item(result));
	}
	
	@Override
	public HandlerList getHandlers()
	{
		return handlers;
	}
	
	public static HandlerList getHandlerList()
	{
		return handlers;
	}
	
	@Override
	public boolean isCancelled()
	{
		return cancelled;
	}
	
	@Override
	public void setCancelled(final boolean cancelled)
	{
		this.cancelled = cancelled;
	}
}
