package digi.recipeManager.customEvents;

import org.bukkit.entity.Player;
import org.bukkit.event.*;
import org.bukkit.inventory.ItemStack;

import digi.recipeManager.data.Recipe;

public class RecipeManagerPreCraftEvent extends Event
{
	private static final HandlerList	handlers	= new HandlerList();
	private ItemStack					result;
	private final Recipe				recipe;
	private final Player				player;
	
	public RecipeManagerPreCraftEvent(final Recipe recipe, final ItemStack result, final Player player)
	{
		this.recipe = recipe;
		this.result = result;
		this.player = player;
	}
	
	/**
	 * @return player or null if crafted by automated plugins
	 */
	public Player getPlayer()
	{
		return player;
	}
	
	public Recipe getRecipe()
	{
		return recipe;
	}
	
	/**
	 * Use getRecipe().getResults().get(0) to get the result that would've been displayed.
	 * 
	 * @return result item or null if player doesn't have access to recipe
	 */
	public ItemStack setDisplayResult()
	{
		return result;
	}
	
	/**
	 * Sets the display result.<br>
	 * Setting this to null will prevent the player from crafting the recipe!
	 * 
	 * @param result
	 *            the ItemStack displayed result or null to 'cancel' event
	 */
	public void setDisplayResult(final ItemStack result)
	{
		this.result = result;
	}
	
	@Override
	public HandlerList getHandlers()
	{
		return handlers;
	}
	
	public static HandlerList getHandlerList()
	{
		return handlers;
	}
}
